@@ -8,7 +8,10 @@ def get_first_day(date):
 
 
 def get_last_day(date):
-    return datetime.date(date.year, date.month, calendar.monthrange(date.year, date.month)[1])
+    return datetime.date(
+        date.year,
+        date.month,
+        calendar.monthrange(date.year, date.month)[1])
 
 
 def subtract_months_for_date(date, months_to_subtract=0):
